@@ -32,6 +32,7 @@ BEGIN {
       run
       installable_hc
       installable_type
+      installable_config_shipper
       source_hc
       hc_libdir
       hc_pkgdir
@@ -44,6 +45,7 @@ BEGIN {
       own_cabal_prerequisites
       hashed_id_to_virtual_installable
       config_to_package_id
+      init_hs_env
       clean_recipe
       make_setup_recipe
       configure_recipe
@@ -185,6 +187,27 @@ sub installable_type {
     return $EMPTY;
 }
 
+=item installable_config_shipper
+
+=cut
+
+sub installable_config_shipper {
+    my ($installable) = @_;
+
+    if ($installable =~ m{^ ( lib .* ) - ( [^-]+) $}x) {
+
+        my $prefix = $1;
+        my $type = $2;
+
+        return $installable
+            if $type eq 'dev';
+
+        return "$prefix-dev";
+    }
+
+    return $EMPTY;
+}
+
 =item source_hc
 
 =cut
@@ -500,6 +523,48 @@ sub config_to_package_id {
     return $package_id;
 }
 
+=item init_hs_env
+
+=cut
+
+sub init_hs_env {
+    $ENV{DEB_DEFAULT_COMPILER} //= 'ghc';
+
+    $ENV{DEB_GHC_DATABASE} = 'debian/tmp-db';
+
+    my @cabal_candidates = glob('*.cabal');
+
+    error('No cabal file found')
+      unless @cabal_candidates;
+
+    error('More than one cabal file')
+      if @cabal_candidates > 1;
+
+    my $cabal_path = $cabal_candidates[0];
+    my $cabal_contents = path($cabal_path)->slurp_utf8;
+
+    error('Cannot get package name from cabal file')
+      unless $cabal_contents =~ /^ name \s* : \s* (\S*) \s* $/imx;
+
+    my $package_name = lc $1;
+
+    $ENV{CABAL_PACKAGE} //= $package_name;
+
+    error('Cannot get package version from cabal file')
+      unless $cabal_contents =~ /^ version \s* : \s* (\S*) \s* $/imx;
+
+    my $package_version = $1;
+
+    $ENV{CABAL_VERSION} = $package_version;
+
+    $ENV{DEB_ENABLE_TESTS} //= 'no';
+    $ENV{DEB_ENABLE_HOOGLE} //= 'yes';
+
+    $ENV{DEB_SETUP_BIN_NAME} //= 'debian/hlibrary.setup';
+
+    return;
+}
+
 =item clean_recipe
 
 =cut
